@@ -14,7 +14,6 @@
 
 from __future__ import annotations
 
-from pprint import pprint
 from typing import List, Callable, Union, Tuple, Optional
 
 import firefly.domain as ffd
@@ -22,12 +21,14 @@ import firefly.infrastructure as ffi
 import inflection
 from firefly.domain.repository.repository import T
 
+from .abstract_repository import AbstractRepository
+
 DEFAULT_LIMIT = 999999999999999999
 
 
-class RdbRepository(ffd.Repository[T]):
+class RdbRepository(AbstractRepository[T]):
     def __init__(self, interface: ffi.RdbStorageInterface, table_name: str = None):
-        super().__init__()
+        super().__init__(interface=interface)
 
         self._entity_type = self._type()
         self._table = table_name or inflection.tableize(self._entity_type.get_fqn())
